@@ -199,7 +199,10 @@ MixxxApp::MixxxApp(QApplication * a, struct CmdlineArgs args)
     QDir dir(config->getValueString(ConfigKey("[Playlist]","Directory")));
     if ((config->getValueString(ConfigKey("[Playlist]","Directory")).length()<1) || (!dir.exists()))
     {
-        QString fd = QFileDialog::getExistingDirectory(this, "Choose music library directory");
+        QString fd = QFileDialog::getExistingDirectory(this, 
+                         tr("Choose music library directory"),
+                         QDesktopServices::storageLocation(QDesktopServices::MusicLocation));
+        
         if (fd != "")
         {
             config->set(ConfigKey("[Playlist]","Directory"), fd);
@@ -852,6 +855,8 @@ void MixxxApp::slotiPodToggle(bool toggle) {
     //m_pTrack->m_qIPodPlaylist.clear();
 
   }
+#else
+  Q_UNUSED(toggle); // suppress gcc unused parameter warning
 #endif
 }
 
@@ -1305,7 +1310,7 @@ bool MixxxApp::eventFilter(QObject *obj, QEvent *event)
     static int tooltips = config->getValueString(ConfigKey("[Controls]","Tooltips")).toInt();
 
     if (event->type() == QEvent::ToolTip) {
-        QKeyEvent *keyEvent = static_cast<QKeyEvent *>(event);
+        // QKeyEvent *keyEvent = static_cast<QKeyEvent *>(event); // unused, remove? TODO(bkgood)
         if (tooltips == 1)
             return false;
         else
@@ -1372,3 +1377,4 @@ void MixxxApp::slotEnableRescanLibraryAction()
 {
     libraryRescan->setEnabled(true);
 }
+
